==> gorilla-notes-0.5.0-20200922.072747-2.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Facebook.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$players$Facebook=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,
staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==
typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in
obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Facebook=void 0;var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,
key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));
var MATCH_URL=/^https?:\/\/(www\.)?facebook\.com.*\/(video(s)?|watch|story)(\.php?|\/).+$/;require=function(_Component){function Facebook(){if(!(this instanceof Facebook))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),
"playerID",_this.props.config.facebook.playerId||"".concat("facebook-player-").concat((0,_utils.randomString)()));_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("mute")});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("unmute")});return _this}_inherits(Facebook,_Component);var _super=_createSuper(Facebook);_createClass(Facebook,[{key:"load",value:function(url,isReady){var _this2=this;isReady?(0,_utils.getSDK)("https://connect.facebook.net/en_US/sdk.js",
"FB","fbAsyncInit").then(function(FB){return FB.XFBML.parse()}):(0,_utils.getSDK)("https://connect.facebook.net/en_US/sdk.js","FB","fbAsyncInit").then(function(FB){FB.init({appId:_this2.props.config.facebook.appId,xfbml:!0,version:_this2.props.config.facebook.version});FB.Event.subscribe("xfbml.render",function(msg){_this2.props.onLoaded()});FB.Event.subscribe("xfbml.ready",function(msg){"video"===msg.type&&msg.id===_this2.playerID&&(_this2.player=msg.instance,_this2.player.subscribe("startedPlaying",
_this2.props.onPlay),_this2.player.subscribe("paused",_this2.props.onPause),_this2.player.subscribe("finishedPlaying",_this2.props.onEnded),_this2.player.subscribe("startedBuffering",_this2.props.onBuffer),_this2.player.subscribe("finishedBuffering",_this2.props.onBufferEnd),_this2.player.subscribe("error",_this2.props.onError),_this2.props.muted||_this2.callPlayer("unmute"),_this2.props.onReady(),document.getElementById(_this2.playerID).querySelector("iframe").style.visibility="visible")})})}},{key:"play",
value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){}},{key:"seekTo",value:function(seconds){this.callPlayer("seek",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},{key:"getDuration",value:function(){return this.callPlayer("getDuration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("getCurrentPosition")}},{key:"getSecondsLoaded",value:function(){return null}},
{key:"render",value:function(){return _react["default"].createElement("div",{style:{width:"100%",height:"100%"},id:this.playerID,className:"fb-video","data-href":this.props.url,"data-autoplay":this.props.playing?"true":"false","data-allowfullscreen":"true","data-controls":this.props.controls?"true":"false"})}}]);return Facebook}(_react.Component);exports.Facebook=require;_defineProperty(require,"displayName","Facebook");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});
_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Facebook.js.map

==> gorilla-notes-0.5.1.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$Facebook.js <==
shadow$provide.module$node_modules$react_player$lib$players$Facebook=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,
staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==
typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in
obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.Facebook=void 0;var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&
Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));
var MATCH_URL=/^https?:\/\/(www\.)?facebook\.com.*\/(video(s)?|watch|story)(\.php?|\/).+$/;require=function(_Component){function Facebook(){if(!(this instanceof Facebook))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),
"playerID",_this.props.config.facebook.playerId||"".concat("facebook-player-").concat((0,_utils.randomString)()));_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("mute")});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("unmute")});return _this}_inherits(Facebook,_Component);var _super=_createSuper(Facebook);_createClass(Facebook,[{key:"load",value:function(url,isReady){var _this2=this;isReady?(0,_utils.getSDK)("https://connect.facebook.net/en_US/sdk.js",
"FB","fbAsyncInit").then(function(FB){return FB.XFBML.parse()}):(0,_utils.getSDK)("https://connect.facebook.net/en_US/sdk.js","FB","fbAsyncInit").then(function(FB){FB.init({appId:_this2.props.config.facebook.appId,xfbml:!0,version:_this2.props.config.facebook.version});FB.Event.subscribe("xfbml.render",function(msg){_this2.props.onLoaded()});FB.Event.subscribe("xfbml.ready",function(msg){"video"===msg.type&&msg.id===_this2.playerID&&(_this2.player=msg.instance,_this2.player.subscribe("startedPlaying",
_this2.props.onPlay),_this2.player.subscribe("paused",_this2.props.onPause),_this2.player.subscribe("finishedPlaying",_this2.props.onEnded),_this2.player.subscribe("startedBuffering",_this2.props.onBuffer),_this2.player.subscribe("finishedBuffering",_this2.props.onBufferEnd),_this2.player.subscribe("error",_this2.props.onError),_this2.props.muted||_this2.callPlayer("unmute"),_this2.props.onReady(),document.getElementById(_this2.playerID).querySelector("iframe").style.visibility="visible")})})}},{key:"play",
value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){}},{key:"seekTo",value:function(seconds){this.callPlayer("seek",seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",fraction)}},{key:"getDuration",value:function(){return this.callPlayer("getDuration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("getCurrentPosition")}},{key:"getSecondsLoaded",value:function(){return null}},
{key:"render",value:function(){return _react["default"].createElement("div",{style:{width:"100%",height:"100%"},id:this.playerID,className:"fb-video","data-href":this.props.url,"data-autoplay":this.props.playing?"true":"false","data-allowfullscreen":"true","data-controls":this.props.controls?"true":"false"})}}]);return Facebook}(_react.Component);exports.Facebook=require;_defineProperty(require,"displayName","Facebook");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});
_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$Facebook.js.map
